# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased](https://github.com/wagtail/wagtail-bakery/compare/0.4.0...HEAD)

...

## [0.4.0](https://github.com/wagtail/wagtail-bakery/compare/0.3.0...0.4.0)

- Use model url from inherited model (#42)
- Allow use of new versions of django-bakery (#44)
- Drop support for Wagtail < 2.6, Django < 2.x & Python < 3.5 (#45, #46)

## [0.3.0](https://github.com/wagtail/wagtail-bakery/compare/0.2.0...0.3.0)

### Added

- Compatibility with Wagtail 2.0 (#27, #31, #32, #33)

### Fixed

- UTF8 decoding with Python 3 (#28)

## [0.2.0](https://github.com/wagtail/wagtail-bakery/compare/0.1.0...0.2.0)

### Added

- MIT License
- Support for generating a static API

## [0.1.0](https://github.com/wagtail/wagtail-bakery/compare/8ad37f6a733699c339bd50a965cc1b0387898205...0.1.0)

Initial Release
